============
Requirements
============

.. item:: RQT-SUMMATION System shall be able to calculate a sum

.. item:: RQT-LOGGING System shall be able to log messages

.. item:: RQT-DIRECTORY System shall have a directory called 'projects' in its root directory
